@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-    
 def getDefinitions(vmanage):
     """
     Get policy definitions
@@ -13,8 +10,8 @@ def getDefinitions(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/urlfiltering"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/definition/urlfiltering"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def create(vmanage, policydefinition):
     """
@@ -29,8 +26,8 @@ def create(vmanage, policydefinition):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/urlfiltering"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policydefinition)
+    endpoint = f"dataservice/template/policy/definition/urlfiltering"
+    response = vmanage.apiCall("POST", endpoint, policydefinition)
     return response
 def saveInBulk(vmanage, policydefinition):
     """
@@ -45,8 +42,8 @@ def saveInBulk(vmanage, policydefinition):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/urlfiltering/bulk"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policydefinition)
+    endpoint = f"dataservice/template/policy/definition/urlfiltering/bulk"
+    response = vmanage.apiCall("PUT", endpoint, policydefinition)
     return response
 def editMultiple(vmanage, policydefinition, id):
     """
@@ -62,8 +59,8 @@ def editMultiple(vmanage, policydefinition, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/urlfiltering/multiple/{id}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policydefinition)
+    endpoint = f"dataservice/template/policy/definition/urlfiltering/multiple/{id}"
+    response = vmanage.apiCall("PUT", endpoint, policydefinition)
     return response
 def preview(vmanage, policydefinition):
     """
@@ -78,8 +75,8 @@ def preview(vmanage, policydefinition):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/urlfiltering/preview"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policydefinition)
+    endpoint = f"dataservice/template/policy/definition/urlfiltering/preview"
+    response = vmanage.apiCall("POST", endpoint, policydefinition)
     return response
 def previewById(vmanage, id):
     """
@@ -94,8 +91,8 @@ def previewById(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/urlfiltering/preview/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/definition/urlfiltering/preview/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def get(vmanage, id):
     """
@@ -110,8 +107,8 @@ def get(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/urlfiltering/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/definition/urlfiltering/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def edit(vmanage, policydefinition, id):
     """
@@ -127,8 +124,8 @@ def edit(vmanage, policydefinition, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/urlfiltering/{id}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policydefinition)
+    endpoint = f"dataservice/template/policy/definition/urlfiltering/{id}"
+    response = vmanage.apiCall("PUT", endpoint, policydefinition)
     return response
 def delete(vmanage, id):
     """
@@ -143,6 +140,6 @@ def delete(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/urlfiltering/{id}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/template/policy/definition/urlfiltering/{id}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
