@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getCORStatus(vmanage):
     """
     Get Cloud On Ramp list
@@ -13,8 +10,8 @@ def getCORStatus(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def createAndMap(vmanage, request):
@@ -30,8 +27,8 @@ def createAndMap(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, request)
+    endpoint = f"dataservice/template/cor"
+    response = vmanage.apiCall("POST", endpoint, request)
     return response
 
 def raiseAlarmForAccount(vmanage, accountobject):
@@ -47,8 +44,8 @@ def raiseAlarmForAccount(vmanage, accountobject):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/account/alarm"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, accountobject)
+    endpoint = f"dataservice/template/cor/account/alarm"
+    response = vmanage.apiCall("POST", endpoint, accountobject)
     return response
 
 def removeTransitVPC(vmanage, accountid, transitvpcid, cloudregion, cloudtype):
@@ -67,8 +64,8 @@ def removeTransitVPC(vmanage, accountid, transitvpcid, cloudregion, cloudtype):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/accountid/{accountid}?transitvpcid={transitvpcid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/template/cor/accountid/{accountid}?transitvpcid={transitvpcid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
 
 def acquireRP(vmanage, request):
@@ -84,8 +81,8 @@ def acquireRP(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/acquireResourcePool"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, request)
+    endpoint = f"dataservice/template/cor/acquireResourcePool"
+    response = vmanage.apiCall("POST", endpoint, request)
     return response
 
 def getAmiList(vmanage, accountid, cloudregion, cloudtype):
@@ -103,8 +100,8 @@ def getAmiList(vmanage, accountid, cloudregion, cloudtype):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/ami?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/ami?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getCloudList(vmanage):
@@ -119,8 +116,8 @@ def getCloudList(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/cloud"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/cloud"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getCloudAccounts(vmanage, cloudtype, cloudEnvironment):
@@ -137,8 +134,8 @@ def getCloudAccounts(vmanage, cloudtype, cloudEnvironment):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/cloud/account?cloudtype={cloudtype}&cloudEnvironment={cloudEnvironment}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/cloud/account?cloudtype={cloudtype}&cloudEnvironment={cloudEnvironment}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def authCredAndUpdate(vmanage, credential):
@@ -154,8 +151,8 @@ def authCredAndUpdate(vmanage, credential):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/cloud/authenticate"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, credential)
+    endpoint = f"dataservice/template/cor/cloud/authenticate"
+    response = vmanage.apiCall("PUT", endpoint, credential)
     return response
 
 def authCORCredAndAdd(vmanage, credential):
@@ -171,8 +168,8 @@ def authCORCredAndAdd(vmanage, credential):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/cloud/authenticate"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, credential)
+    endpoint = f"dataservice/template/cor/cloud/authenticate"
+    response = vmanage.apiCall("POST", endpoint, credential)
     return response
 
 def getCloudHostVpcAccountDetails(vmanage):
@@ -187,8 +184,8 @@ def getCloudHostVpcAccountDetails(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/cloud/host/accountdetails"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/cloud/host/accountdetails"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getCloudMappedHostAccounts(vmanage, accountid, cloudtype):
@@ -205,8 +202,8 @@ def getCloudMappedHostAccounts(vmanage, accountid, cloudtype):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/cloud/mappedhostaccounts?accountid={accountid}&cloudtype={cloudtype}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/cloud/mappedhostaccounts?accountid={accountid}&cloudtype={cloudtype}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def createRP(vmanage, request):
@@ -222,8 +219,8 @@ def createRP(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/createResourcePool"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, request)
+    endpoint = f"dataservice/template/cor/createResourcePool"
+    response = vmanage.apiCall("POST", endpoint, request)
     return response
 
 def removeDeviceId(vmanage, accountid, transitvpcid, transitvpcname, cloudregion, cloudtype, devicePairId):
@@ -244,8 +241,8 @@ def removeDeviceId(vmanage, accountid, transitvpcid, transitvpcname, cloudregion
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/deleteDevicepair?accountid={accountid}&transitvpcid={transitvpcid}&transitvpcname={transitvpcname}&cloudregion={cloudregion}&cloudtype={cloudtype}&devicePairId={devicePairId}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/template/cor/deleteDevicepair?accountid={accountid}&transitvpcid={transitvpcid}&transitvpcname={transitvpcname}&cloudregion={cloudregion}&cloudtype={cloudtype}&devicePairId={devicePairId}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
 
 def getCORDevices(vmanage):
@@ -260,8 +257,8 @@ def getCORDevices(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/device"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/device"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def addDevicePair(vmanage, request):
@@ -277,8 +274,8 @@ def addDevicePair(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/devicepair"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, request)
+    endpoint = f"dataservice/template/cor/devicepair"
+    response = vmanage.apiCall("POST", endpoint, request)
     return response
 
 def getHostVPCs(vmanage, transitVpcId, devicePairId):
@@ -295,8 +292,8 @@ def getHostVPCs(vmanage, transitVpcId, devicePairId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/devicepair/hostvpc?transitVpcId={transitVpcId}&devicePairId={devicePairId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/devicepair/hostvpc?transitVpcId={transitVpcId}&devicePairId={devicePairId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getExternalId(vmanage):
@@ -311,8 +308,8 @@ def getExternalId(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/externalId"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/externalId"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getTransitDevicePairAndHostList(vmanage, accountId, cloudRegion):
@@ -329,8 +326,8 @@ def getTransitDevicePairAndHostList(vmanage, accountId, cloudRegion):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/getTransitDevicePairAndHostList?accountId={accountId}&cloudRegion={cloudRegion}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/getTransitDevicePairAndHostList?accountId={accountId}&cloudRegion={cloudRegion}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getTransitVpcVpnList(vmanage, accountId):
@@ -346,8 +343,8 @@ def getTransitVpcVpnList(vmanage, accountId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/getTransitVpnList?accountId={accountId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/getTransitVpnList?accountId={accountId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getCloudHostVPCs(vmanage, accountid, cloudregion, cloudtype):
@@ -365,8 +362,8 @@ def getCloudHostVPCs(vmanage, accountid, cloudregion, cloudtype):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/hostvpc?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/hostvpc?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getTenantAndHostVpcList(vmanage, intent):
@@ -382,8 +379,8 @@ def getTenantAndHostVpcList(vmanage, intent):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/hostvpclist?intent={intent}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/hostvpclist?intent={intent}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def updateHostVpcReachability(vmanage, updatevpcstatus):
@@ -399,8 +396,8 @@ def updateHostVpcReachability(vmanage, updatevpcstatus):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/hostvpclist"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, updatevpcstatus)
+    endpoint = f"dataservice/template/cor/hostvpclist"
+    response = vmanage.apiCall("PUT", endpoint, updatevpcstatus)
     return response
 
 def getMappedVPCs(vmanage, accountid, cloudregion):
@@ -417,8 +414,8 @@ def getMappedVPCs(vmanage, accountid, cloudregion):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/map?accountid={accountid}&cloudregion={cloudregion}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/map?accountid={accountid}&cloudregion={cloudregion}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def mapVPCs(vmanage, host):
@@ -434,8 +431,8 @@ def mapVPCs(vmanage, host):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/map"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, host)
+    endpoint = f"dataservice/template/cor/map"
+    response = vmanage.apiCall("POST", endpoint, host)
     return response
 
 def unmapVPCs(vmanage, host):
@@ -451,8 +448,8 @@ def unmapVPCs(vmanage, host):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/map"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint, host)
+    endpoint = f"dataservice/template/cor/map"
+    response = vmanage.apiCall("DELETE", endpoint, host)
     return response
 
 def getPemKeyList(vmanage, accountid, cloudregion, cloudtype):
@@ -470,8 +467,8 @@ def getPemKeyList(vmanage, accountid, cloudregion, cloudtype):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/pem?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/pem?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def scaleDown(vmanage, updatevpc):
@@ -487,8 +484,8 @@ def scaleDown(vmanage, updatevpc):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/scale/down"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, updatevpc)
+    endpoint = f"dataservice/template/cor/scale/down"
+    response = vmanage.apiCall("POST", endpoint, updatevpc)
     return response
 
 def scaleUp(vmanage, updatevpc):
@@ -504,8 +501,8 @@ def scaleUp(vmanage, updatevpc):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/scale/up"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, updatevpc)
+    endpoint = f"dataservice/template/cor/scale/up"
+    response = vmanage.apiCall("POST", endpoint, updatevpc)
     return response
 
 def updatestatus(vmanage, statusobject):
@@ -521,8 +518,8 @@ def updatestatus(vmanage, statusobject):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/status"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, statusobject)
+    endpoint = f"dataservice/template/cor/status"
+    response = vmanage.apiCall("POST", endpoint, statusobject)
     return response
 
 def getTransitVPCs(vmanage, accountid, cloudregion, cloudtype):
@@ -540,8 +537,8 @@ def getTransitVPCs(vmanage, accountid, cloudregion, cloudtype):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/transitvpc?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/transitvpc?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def updateTransitVPC(vmanage, vpc):
@@ -557,8 +554,8 @@ def updateTransitVPC(vmanage, vpc):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/transitvpc"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, vpc)
+    endpoint = f"dataservice/template/cor/transitvpc"
+    response = vmanage.apiCall("PUT", endpoint, vpc)
     return response
 
 def addTransitVPC(vmanage, vpc):
@@ -574,8 +571,8 @@ def addTransitVPC(vmanage, vpc):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/transitvpc"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, vpc)
+    endpoint = f"dataservice/template/cor/transitvpc"
+    response = vmanage.apiCall("POST", endpoint, vpc)
     return response
 
 def updateTransitVpcAutoscaleProperties(vmanage, vpc):
@@ -591,8 +588,8 @@ def updateTransitVpcAutoscaleProperties(vmanage, vpc):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/transitvpc/autoscale-properties"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, vpc)
+    endpoint = f"dataservice/template/cor/transitvpc/autoscale-properties"
+    response = vmanage.apiCall("PUT", endpoint, vpc)
     return response
 
 def getTransitVPCSupportedSize(vmanage, cloudtype, cloudEnvironment):
@@ -609,6 +606,6 @@ def getTransitVPCSupportedSize(vmanage, cloudtype, cloudEnvironment):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cor/transitvpc/size?cloudtype={cloudtype}&cloudEnvironment={cloudEnvironment}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cor/transitvpc/size?cloudtype={cloudtype}&cloudEnvironment={cloudEnvironment}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
