@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getAllocInfo(vmanage, deviceId):
     """
     Get NetworkHub CPU allocation info from device
@@ -14,8 +11,8 @@ def getAllocInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/csp/resources/cpu-info/allocation?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/csp/resources/cpu-info/allocation?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getCPUInfo(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getCPUInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/csp/resources/cpu-info/cpus?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/csp/resources/cpu-info/cpus?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getVNFInfo(vmanage, deviceId):
     """
@@ -46,6 +43,6 @@ def getVNFInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/csp/resources/cpu-info/vnfs?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/csp/resources/cpu-info/vnfs?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
