@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getInterfaceList(vmanage, deviceId):
     """
     Get PPPoE session list from device
@@ -14,8 +11,8 @@ def getInterfaceList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/pppoe/session?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/pppoe/session?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getNeighborList(vmanage, deviceId):
     """
@@ -30,6 +27,6 @@ def getNeighborList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/pppoe/statistic?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/pppoe/statistic?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
