@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getClients(vmanage, deviceId):
     """
     Get wireless clients from device
@@ -14,8 +11,8 @@ def getClients(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/wireless/client?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/wireless/client?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getRadios(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getRadios(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/wireless/radio?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/wireless/radio?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSsid(vmanage, deviceId):
     """
@@ -46,6 +43,6 @@ def getSsid(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/wireless/ssid?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/wireless/ssid?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
